"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.entry import Entry
from cvg_sdk.model.external_call_id import ExternalCallId
globals()['Entry'] = Entry
globals()['ExternalCallId'] = ExternalCallId
from cvg_sdk.model.dialog import Dialog


class TestDialog(unittest.TestCase):
    """Dialog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDialog(self):
        """Test Dialog"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Dialog()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
