"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.answer_type import AnswerType
from cvg_sdk.model.multiple_choice_answer import MultipleChoiceAnswer
from cvg_sdk.model.number_answer import NumberAnswer
from cvg_sdk.model.timeout_answer import TimeoutAnswer
globals()['AnswerType'] = AnswerType
globals()['MultipleChoiceAnswer'] = MultipleChoiceAnswer
globals()['NumberAnswer'] = NumberAnswer
globals()['TimeoutAnswer'] = TimeoutAnswer
from cvg_sdk.model.timeout_answer import TimeoutAnswer


class TestTimeoutAnswer(unittest.TestCase):
    """TimeoutAnswer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTimeoutAnswer(self):
        """Test TimeoutAnswer"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TimeoutAnswer()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
