"""
    VIER Cognitive Voice Assist API

    With the CVG Assist API you can use live transcriptions of customers to provide in-call agent assistance.  CVG Assist API requires some integration with contact center software to link ACD phone number, dialogID und agentID. The call has to be bridged to the contact center head number of e.g. a hotline plus an extension. The contact center then has to invoke `/assist/accept` with the phone number.  Integration with VIER Engage is available. Ask us if you are interested in integrating other contact center software.  CVG Assist API is part of the VIER Cognitive Voice Gateway.  For more details, see [our documentation](/docs/Essential-Use-Cases.html#agent-assistance).  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.assist_recording_start_parameters_all_of import AssistRecordingStartParametersAllOf


class TestAssistRecordingStartParametersAllOf(unittest.TestCase):
    """AssistRecordingStartParametersAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAssistRecordingStartParametersAllOf(self):
        """Test AssistRecordingStartParametersAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AssistRecordingStartParametersAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
