"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.confidence import Confidence
globals()['Confidence'] = Confidence
from cvg_sdk.model.voice_all_of import VoiceAllOf


class TestVoiceAllOf(unittest.TestCase):
    """VoiceAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVoiceAllOf(self):
        """Test VoiceAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = VoiceAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
