"""
    VIER Cognitive Voice Assist API

    With the CVG Assist API you can use live transcriptions of customers to provide in-call agent assistance.  CVG Assist API requires some integration with contact center software to link ACD phone number, dialogID und agentID. The call has to be bridged to the contact center head number of e.g. a hotline plus an extension. The contact center then has to invoke `/assist/accept` with the phone number.  Integration with VIER Engage is available. Ask us if you are interested in integrating other contact center software.  CVG Assist API is part of the VIER Cognitive Voice Gateway.  For more details, see [our documentation](/docs/Essential-Use-Cases.html#agent-assistance).  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.assist_api import AssistApi  # noqa: E501


class TestAssistApi(unittest.TestCase):
    """AssistApi unit test stubs"""

    def setUp(self):
        self.api = AssistApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_assist(self):
        """Test case for accept_assist

        Accept assist  # noqa: E501
        """
        pass

    def test_start_recording(self):
        """Test case for start_recording

        Start or resume recording of the call  # noqa: E501
        """
        pass

    def test_start_transcription(self):
        """Test case for start_transcription

        Start transcription  # noqa: E501
        """
        pass

    def test_stop_recording(self):
        """Test case for stop_recording

        Pause or terminate recording of the call  # noqa: E501
        """
        pass

    def test_stop_transcription(self):
        """Test case for stop_transcription

        Stop transcription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
