"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.dialog_api import DialogApi  # noqa: E501


class TestDialogApi(unittest.TestCase):
    """DialogApi unit test stubs"""

    def setUp(self):
        self.api = DialogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_custom_data(self):
        """Test case for attach_custom_data

        Attach custom data to a dialog  # noqa: E501
        """
        pass

    def test_delete_dialog(self):
        """Test case for delete_dialog

        Delete dialog by dialog ID  # noqa: E501
        """
        pass

    def test_get_dialog(self):
        """Test case for get_dialog

        Get dialog by dialog ID  # noqa: E501
        """
        pass

    def test_get_dialog_by_external_call_id(self):
        """Test case for get_dialog_by_external_call_id

        Get dialog by external call ID  # noqa: E501
        """
        pass

    def test_get_single_entry(self):
        """Test case for get_single_entry

        Get a single custom dialog data entry  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
