"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.recording_id import RecordingId
globals()['RecordingId'] = RecordingId
from cvg_sdk.model.recording_start_all_of import RecordingStartAllOf


class TestRecordingStartAllOf(unittest.TestCase):
    """RecordingStartAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRecordingStartAllOf(self):
        """Test RecordingStartAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RecordingStartAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
