"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.aggregated_latencies import AggregatedLatencies
from cvg_sdk.model.audio_playback_failed import AudioPlaybackFailed
from cvg_sdk.model.endpoint_call import EndpointCall
from cvg_sdk.model.endpoint_call_all_of import EndpointCallAllOf
from cvg_sdk.model.endpoint_call_failed import EndpointCallFailed
from cvg_sdk.model.health_event_status import HealthEventStatus
from cvg_sdk.model.internal_error import InternalError
from cvg_sdk.model.project_health_event import ProjectHealthEvent
from cvg_sdk.model.provisioning_timed_out import ProvisioningTimedOut
from cvg_sdk.model.synthesis import Synthesis
from cvg_sdk.model.synthesis_failed import SynthesisFailed
from cvg_sdk.model.transcription import Transcription
from cvg_sdk.model.transcription_failed import TranscriptionFailed
globals()['AggregatedLatencies'] = AggregatedLatencies
globals()['AudioPlaybackFailed'] = AudioPlaybackFailed
globals()['EndpointCall'] = EndpointCall
globals()['EndpointCallAllOf'] = EndpointCallAllOf
globals()['EndpointCallFailed'] = EndpointCallFailed
globals()['HealthEventStatus'] = HealthEventStatus
globals()['InternalError'] = InternalError
globals()['ProjectHealthEvent'] = ProjectHealthEvent
globals()['ProvisioningTimedOut'] = ProvisioningTimedOut
globals()['Synthesis'] = Synthesis
globals()['SynthesisFailed'] = SynthesisFailed
globals()['Transcription'] = Transcription
globals()['TranscriptionFailed'] = TranscriptionFailed
from cvg_sdk.model.endpoint_call import EndpointCall


class TestEndpointCall(unittest.TestCase):
    """EndpointCall unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointCall(self):
        """Test EndpointCall"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointCall()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
