"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.language import Language
globals()['Language'] = Language
from cvg_sdk.model.speech_service_configuration import SpeechServiceConfiguration


class TestSpeechServiceConfiguration(unittest.TestCase):
    """SpeechServiceConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSpeechServiceConfiguration(self):
        """Test SpeechServiceConfiguration"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SpeechServiceConfiguration()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
