"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.aggregated_latencies import AggregatedLatencies
globals()['AggregatedLatencies'] = AggregatedLatencies
from cvg_sdk.model.endpoint_call_all_of import EndpointCallAllOf


class TestEndpointCallAllOf(unittest.TestCase):
    """EndpointCallAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointCallAllOf(self):
        """Test EndpointCallAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointCallAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
