"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.multiple_choice_prompt import MultipleChoicePrompt
from cvg_sdk.model.multiple_choice_prompt_all_of import MultipleChoicePromptAllOf
from cvg_sdk.model.number_prompt import NumberPrompt
from cvg_sdk.model.prompt_type import PromptType
from cvg_sdk.model.synonyms import Synonyms
globals()['MultipleChoicePrompt'] = MultipleChoicePrompt
globals()['MultipleChoicePromptAllOf'] = MultipleChoicePromptAllOf
globals()['NumberPrompt'] = NumberPrompt
globals()['PromptType'] = PromptType
globals()['Synonyms'] = Synonyms
from cvg_sdk.model.multiple_choice_prompt import MultipleChoicePrompt


class TestMultipleChoicePrompt(unittest.TestCase):
    """MultipleChoicePrompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultipleChoicePrompt(self):
        """Test MultipleChoicePrompt"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MultipleChoicePrompt()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
