"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.audio import Audio
from cvg_sdk.model.dtmf import Dtmf
from cvg_sdk.model.dtmf_all_of import DtmfAllOf
from cvg_sdk.model.speaker import Speaker
from cvg_sdk.model.text import Text
from cvg_sdk.model.transcript_entry import TranscriptEntry
from cvg_sdk.model.voice import Voice
globals()['Audio'] = Audio
globals()['Dtmf'] = Dtmf
globals()['DtmfAllOf'] = DtmfAllOf
globals()['Speaker'] = Speaker
globals()['Text'] = Text
globals()['TranscriptEntry'] = TranscriptEntry
globals()['Voice'] = Voice
from cvg_sdk.model.dtmf import Dtmf


class TestDtmf(unittest.TestCase):
    """Dtmf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDtmf(self):
        """Test Dtmf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Dtmf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
