"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.recording_api import RecordingApi  # noqa: E501


class TestRecordingApi(unittest.TestCase):
    """RecordingApi unit test stubs"""

    def setUp(self):
        self.api = RecordingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_recording(self):
        """Test case for delete_recording

        Delete recording  # noqa: E501
        """
        pass

    def test_get_recording_artifacts(self):
        """Test case for get_recording_artifacts

        Get download URLs for recording  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
