"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.answer import Answer
from cvg_sdk.model.bridge import Bridge
from cvg_sdk.model.custom import Custom
from cvg_sdk.model.end import End
from cvg_sdk.model.entry import Entry
from cvg_sdk.model.entry_type import EntryType
from cvg_sdk.model.forward import Forward
from cvg_sdk.model.inactivity import Inactivity
from cvg_sdk.model.playback import Playback
from cvg_sdk.model.prompt import Prompt
from cvg_sdk.model.prompt_all_of import PromptAllOf
from cvg_sdk.model.prompt_type import PromptType
from cvg_sdk.model.recording_start import RecordingStart
from cvg_sdk.model.recording_stop import RecordingStop
from cvg_sdk.model.start import Start
from cvg_sdk.model.synthesis import Synthesis
from cvg_sdk.model.tone import Tone
from cvg_sdk.model.transcription import Transcription
globals()['Answer'] = Answer
globals()['Bridge'] = Bridge
globals()['Custom'] = Custom
globals()['End'] = End
globals()['Entry'] = Entry
globals()['EntryType'] = EntryType
globals()['Forward'] = Forward
globals()['Inactivity'] = Inactivity
globals()['Playback'] = Playback
globals()['Prompt'] = Prompt
globals()['PromptAllOf'] = PromptAllOf
globals()['PromptType'] = PromptType
globals()['RecordingStart'] = RecordingStart
globals()['RecordingStop'] = RecordingStop
globals()['Start'] = Start
globals()['Synthesis'] = Synthesis
globals()['Tone'] = Tone
globals()['Transcription'] = Transcription
from cvg_sdk.model.prompt import Prompt


class TestPrompt(unittest.TestCase):
    """Prompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPrompt(self):
        """Test Prompt"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Prompt()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
