"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.health_api import HealthApi  # noqa: E501


class TestHealthApi(unittest.TestCase):
    """HealthApi unit test stubs"""

    def setUp(self):
        self.api = HealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_project_health(self):
        """Test case for get_project_health

        Get the health status of a project based on calls within a time range (by default the last 10 minutes). NOTE: this API is still experimental and subject to change.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
